@@ -880,6 +880,7 @@ bail:
 	if (data->timeout_id > 0)
 		g_source_remove (data->timeout_id);
 
+	g_free (data->device);
 	g_timer_destroy (data->timer);
 	g_free (data);
 }
@@ -1353,9 +1354,6 @@ default_adapter_changed (BluetoothClient  *client,
 	g_debug ("Default adapter changed to: %s", default_adapter ? default_adapter : "(none)");
 
 	g_object_set (G_OBJECT (client), "default-adapter-discovering", default_adapter != NULL, NULL);
-
-	/* FIXME: This should turn off automatically when
-	 * the settings panel goes away */
 	g_object_set (G_OBJECT (client), "default-adapter-discoverable", default_adapter != NULL, NULL);
 
 	g_signal_emit (G_OBJECT (self), signals[ADAPTER_STATUS_CHANGED], 0);
@@ -1977,8 +1975,10 @@ bluetooth_settings_widget_finalize (GObject *object)
 
 	/* See default_adapter_changed () */
 	/* FIXME: This is blocking */
-	if (priv->client)
+	if (priv->client) {
+		g_object_set (G_OBJECT (priv->client), "default-adapter-discovering", FALSE, NULL);
 		g_object_set (G_OBJECT (priv->client), "default-adapter-discoverable", FALSE, NULL);
+	}
 
 	g_cancellable_cancel (priv->cancellable);
 	g_clear_object (&priv->cancellable);
